/**
 * top-left origin rect.
 * Subset of DOMRect, which is returned by `HTMLElement.getBoundingClientRect()`.
 * @internal
 */
export type Rect = {
    left: number;
    right: number;
    top: number;
    bottom: number;
};
export declare function rect(top: number, right: number, bottom: number, left: number): Rect;
export declare const RECT_ZERO: Rect;
/**
 * Values to determine a rectangle area for margin, padding etc.
 */
export type RectOpts = number | [top: number, right: number, bottom: number, left: number] | {
    top?: number;
    right?: number;
    bottom?: number;
    left?: number;
};
export declare function createRect(r: RectOpts): Rect;
export declare function growRect(a: Rect, b: Rect): Rect;
export declare function shrinkRect(a: Rect, b: Rect): Rect;
/**
 * Calculate the ratio of the intersection between two Rect objects.
 * It returns a number between 0 and 1.
 */
export declare function getIntersection(container: Rect, target: Rect): number;
